[![Build & Publish](https://github.com/chanana/ir2json/actions/workflows/build.yml/badge.svg)](https://github.com/chanana/ir2json/actions/workflows/build.yml)

# ir2json

`ir2json` is a python script that converts Bruker OPUS (dotZero `*.0`) files to JSON format

## Installation

```bash
pip install ir2json
```

## Usage

```bash
$ ir2json <path/to/csv/files>
```

The script will make a JSON file in the same location with the same name.
